/*
 * Copyright (C) 2013 - Juan Ferrer Toribio
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SQL_BATCH_H
#define SQL_BATCH_H

#include <glib-object.h>

#define SQL_TYPE_BATCH				(sql_batch_get_type ())
#define SQL_BATCH(obj)				(G_TYPE_CHECK_INSTANCE_CAST (obj, SQL_TYPE_BATCH, SqlBatch))
#define SQL_IS_BATCH(obj)			(G_TYPE_CHECK_INSTANCE_TYPE (obj, SQL_TYPE_BATCH))
#define SQL_BATCH_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST (klass, SQL_TYPE_BATCH, SqlBatchClass))
#define SQL_BATCH_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS (obj, SQL_TYPE_BATCH, SqlBatchClass))

typedef struct _SqlBatch SqlBatch;
typedef struct _SqlBatchClass SqlBatchClass;

struct _SqlBatch
{
	GInitiallyUnowned parent;
	GHashTable * items;
};

struct _SqlBatchClass
{
	/* <private> */
	GInitiallyUnownedClass parent;
};

#include "sql-object.h"

GType		sql_batch_get_type			();
SqlBatch *  sql_batch_new				();
gboolean	sql_batch_is_ready			(SqlBatch * obj);
SqlObject *	sql_batch_get				(SqlBatch * obj, const gchar * id);
void		sql_batch_add				(SqlBatch * obj, const gchar * id, SqlObject * object);
void		sql_batch_add_from_param	(SqlBatch * obj, const gchar * id, GvnParam * param);
void		sql_batch_add_from_value	(SqlBatch * obj, const gchar * id, GType type, gpointer content);
void		sql_batch_remove			(SqlBatch * obj, const gchar * id);
void		sql_batch_merge				(SqlBatch * obj, SqlBatch * batch);
void		sql_batch_changed			(SqlBatch * obj);

#endif